<?php

namespace Kylin\User\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * 用户门面
 *
 * 提供用户服务的静态访问入口。
 */
class KylinUser extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-user';
    }
}
