<?php

namespace Kylin\User\Enums;

/**
 * 用户状态枚举
 */
enum UserStatus: int
{
    case Disabled = 0;
    case Active = 1;
    case Locked = 2;

    public function label(): string
    {
        return match ($this) {
            self::Disabled => '已禁用',
            self::Active => '正常',
            self::Locked => '已锁定',
        };
    }
}
