<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    public function up(): void
    {
        Schema::table('users', function (Blueprint $table) {
            if (!Schema::hasColumn('users', 'age_group')) {
                $table->string('age_group', 20)->default('unknown')->after('password_changed_at')->comment('年龄分组: child/junior_minor/senior_minor/adult/unknown');
            }
        });
    }

    public function down(): void
    {
        Schema::table('users', function (Blueprint $table) {
            $table->dropColumn('age_group');
        });
    }
};
